@@ -25,7 +25,7 @@
  *
  ************************************************************************/
 
-#include "orcus/gnumeric/gnumeric_tokens.hpp"
+#include "gnumeric_tokens.hpp"
 
 namespace orcus {
 
@@ -35,7 +35,6 @@ namespace {
 
 }
 
-tokens gnumeric_tokens =
-    tokens(token_names, token_name_count, nstoken_names, nstoken_name_count);
+tokens gnumeric_tokens = tokens(token_names, token_name_count);
 
 }
\ No newline at end of file
