@@ -55,6 +55,8 @@
 
 #include <boost/unordered_map.hpp>
 
+#define ORCUS_DEBUG_SHEET 0
+
 using namespace std;
 
 namespace orcus { namespace spreadsheet {
@@ -64,7 +66,6 @@ typedef boost::unordered_map<row_t, segment_col_index_type*> cell_format_type;
 
 struct sheet_impl
 {
-
     document& m_doc;
     mutable cell_format_type m_cell_formats;
     row_t m_max_row;
@@ -114,6 +115,10 @@ void sheet::set_string(row_t row, col_t col, size_t sindex)
 {
     ixion::model_context& cxt = mp_impl->m_doc.get_model_context();
     cxt.set_string_cell(ixion::abs_address_t(mp_impl->m_sheet,row,col), sindex);
+
+#if ORCUS_DEBUG_SHEET
+    cout << "sheet::set_string: sheet=" << mp_impl->m_sheet << ", row=" << row << ", col=" << col << ", si=" << sindex << endl;
+#endif
 }
 
 void sheet::set_value(row_t row, col_t col, double value)
@@ -122,6 +127,37 @@ void sheet::set_value(row_t row, col_t col, double value)
     cxt.set_numeric_cell(ixion::abs_address_t(mp_impl->m_sheet,row,col), value);
 }
 
+void sheet::set_bool(row_t row, col_t col, bool value)
+{
+    ixion::model_context& cxt = mp_impl->m_doc.get_model_context();
+    cxt.set_boolean_cell(ixion::abs_address_t(mp_impl->m_sheet,row,col), value);
+}
+
+void sheet::set_date_time(row_t row, col_t col, int year, int month, int day, int hour, int minute, double second)
+{
+    // I'll convert this into a string value for now.
+
+    ostringstream os;
+    os << year << '-';
+    if (month < 10)
+        os << '0';
+    os << month << '-';
+    if (day < 10)
+        os << '0';
+    os << day << 'T';
+    if (hour < 10)
+        os << '0';
+    os << hour << ':';
+    if (minute < 10)
+        os << '0';
+    os << minute << ':';
+    if (second < 10.0)
+        os << '0';
+    os << second;
+    string s = os.str();
+    set_auto(row, col, &s[0], s.size());
+}
+
 void sheet::set_format(row_t row, col_t col, size_t index)
 {
     cell_format_type::iterator itr = mp_impl->m_cell_formats.find(row);
@@ -186,6 +222,18 @@ void sheet::set_shared_formula(row_t row, col_t col, size_t sindex)
     mp_impl->m_doc.insert_dirty_cell(pos);
 }
 
+void sheet::set_array_formula(
+    row_t row, col_t col, formula_grammar_t grammar,
+    const char* p, size_t n, row_t array_rows, col_t array_cols)
+{
+}
+
+void sheet::set_array_formula(
+    row_t row, col_t col, formula_grammar_t grammar,
+    const char* p, size_t n, const char* p_range, size_t n_range)
+{
+}
+
 void sheet::set_formula_result(row_t row, col_t col, const char* p, size_t n)
 {
 }
